@@ -1,6 +1,8 @@
-##' Gradient Descent Algorithm for the 2D case.
+##' Gradient Descent Algorithm for the 2D case
+##'
 ##' This function provids a visual illustration for the process of
-##' minimizing a real-valued function through Gradient Descent Algorithm.
+##' minimizing a real-valued function through Gradient Descent
+##' Algorithm.
 ##'
 ##' Gradient descent is an optimization algorithm. To find a local
 ##' minimum of a function using gradient descent, one takes steps
@@ -14,7 +16,6 @@
 ##' of minimization; they will go to a local minimum in the end if the
 ##' maximum number of iterations \code{ani.options('nmax')} has not
 ##' been reached.
-##'
 ##' @param FUN a bivariate objective function to be minimized
 ##' (variable names do not have to be \code{x} and \code{y}); if the
 ##' gradient argument \code{gr} is \code{NULL},
@@ -68,53 +69,7 @@
 ##'
 ##' \url{http://animation.yihui.name/compstat:gradient_descent_algorithm}
 ##' @keywords optimize dynamic dplot
-##' @examples
-##'
-##' ## default example
-##' oopt = ani.options(interval = 0.3, nmax = ifelse(interactive(), 50, 2))
-##' xx = grad.desc()
-##' xx$par  # solution
-##' xx$persp(col = "lightblue", phi = 30)   # perspective plot
-##'
-##' ## define more complex functions; a little time-consuming
-##' f1 = function(x, y) x^2 + 3 * sin(y)
-##' xx = grad.desc(f1, pi * c(-2, -2, 2, 2), c(-2 * pi, 2))
-##' xx$persp(col = "lightblue", theta = 30, phi = 30)
-##'
-##' ## need to provide the gradient when deriv() cannot handle the function
-##' grad.desc(FUN = function(x1, x2) {
-##'     x0 = cos(x2)
-##'     x1^2 + x0
-##' }, gr = function(x1, x2) {
-##'     c(2 * x1, -sin(x2))
-##' }, rg = c(-3, -1, 3, 5), init = c(-3, 0.5),
-##' main = expression(x[1]^2+cos(x[2])))
-##'
-##' ## or a even more complicated function
-##' ani.options(interval = 0, nmax = ifelse(interactive(), 200, 2))
-##' f2 = function(x, y) sin(1/2 * x^2 - 1/4 * y^2 + 3) *
-##'     cos(2 * x + 1 - exp(y))
-##' xx = grad.desc(f2, c(-2, -2, 2, 2), c(-1, 0.5),
-##'     gamma = 0.1, tol = 1e-04)
-##'
-##' ## click your mouse to select a start point
-##' if (interactive()) {
-##' xx = grad.desc(f2, c(-2, -2, 2, 2), interact = TRUE,
-##'     tol = 1e-04)
-##' xx$persp(col = "lightblue", theta = 30, phi = 30)
-##' }
-##'
-##' ## HTML animation pages
-##' saveHTML({
-##' ani.options(interval = 0.3)
-##' grad.desc()
-##' }, img.name='grad.desc',htmlfile='grad.desc.html',
-##' ani.height = 500, ani.width = 500,
-##'     title = "Demonstration of the Gradient Descent Algorithm",
-##'     description = "The arrows will take you to the optimum step by step.")
-##'
-##' ani.options(oopt)
-##'
+##' @example inst/examples/grad.desc-ex.R
 grad.desc = function(FUN = function(x, y) x^2 + 2 *
     y^2, rg = c(-3, -3, 3, 3), init = c(-3, 3), gamma = 0.05,
     tol = 0.001, gr = NULL, len = 50, interact = FALSE, col.contour = "red",
@@ -145,6 +100,7 @@ grad.desc = function(FUN = function(x, y) x^2 + 2 *
         main = eval(substitute(expression(z == x), list(x = body(FUN))))
     i = 1
     while (gap > tol && i <= nmax) {
+        dev.hold()
         contour(x, y, z, col = col.contour, xlab = nms[1], ylab = nms[2],
             main = main)
         xy = rbind(xy, newxy[i, ])
