@@ -1,11 +1,13 @@
-##' A wrapper for the `convert' utility of ImageMagick or GraphicsMagick.
-##' The main purpose of these two functions is to create GIF animations.
+##' A wrapper for the `convert' utility of ImageMagick or
+##' GraphicsMagick
 ##'
-##' the function \code{im.convert} simply wraps the arguments of the
+##' The main purpose of these two functions is to create GIF
+##' animations.
+##'
+##' The function \code{im.convert} simply wraps the arguments of the
 ##' \command{convert} utility of ImageMagick to make it easier to call
 ##' ImageMagick in R;
 ##'
-##' @aliases im.convert gm.convert
 ##' @rdname convert
 ##' @param files either a character vector of file names, or a single
 ##' string containing wildcards (e.g. \file{Rplot*.png})
@@ -23,8 +25,7 @@
 ##' @param extra.opts additional options to be passed to
 ##' \command{convert} (or \command{gm convert})
 ##' @param clean logical: delete the input \code{files} or not
-##' @return The path of the output if the command was successfully
-##' executed; otherwise a failure message.
+##' @return The command for the conversion.
 ##'
 ##' If \code{ani.options('autobrowse') == TRUE}, this function will
 ##' also try to open the output automatically.
@@ -32,6 +33,11 @@
 ##' order of filenames is correct! The first animation frame will be
 ##' \code{files[1]}, the second frame will be \code{files[2]}, ...
 ##'
+##' Both ImageMagick and GraphicsMagick may have a limit on the number
+##' of images to be converted. It is a known issue that this function
+##' can fail with more than (approximately) 9000 images. The function
+##' \code{\link{saveVideo}} is a better alternative in such a case.
+##'
 ##' Most Windows users do not have read the boring notes below after
 ##' they have installed ImageMagick or GraphicsMagick. For the rest of
 ##' Windows users:
@@ -74,27 +80,7 @@
 ##' ImageMagick: \url{http://www.imagemagick.org/script/convert.php}
 ##'
 ##' GraphicsMagick: \url{http://www.graphicsmagick.org}
-##' @examples
-##' ## generate some images
-##' owd = setwd(tempdir())
-##' oopt = ani.options(interval = 0.05, nmax = 20)
-##' png("bm%03d.png")
-##' brownian.motion(pch = 21, cex = 5, col = "red", bg = "yellow",
-##' main = "Demonstration of Brownian Motion")
-##' dev.off()
-##'
-##' ## filenames with a wildcard *
-##' im.convert("bm*.png", output = "bm-animation1.gif")
-##' ## use GraphicsMagick
-##' gm.convert("bm*.png", output = "bm-animation2.gif")
-##'
-##' ## or a filename vector
-##' bm.files = sprintf("bm%03d.png", 1:20)
-##' im.convert(files = bm.files, output = "bm-animation3.gif")
-##'
-##' ani.options(oopt)
-##' setwd(owd)
-##'
+##' @example inst/examples/im.convert-ex.R
 im.convert = function(files, output = "animation.gif", convert = c("convert",
                                                        "gm convert"),
                       cmd.fun = system, extra.opts = "", clean = FALSE) {
@@ -125,17 +111,15 @@ im.convert = function(files, output = "animation.gif", convert = c("convert",
                         message("but I can find it from the Registry Hive: ",
                                 magick.path)
                     }
-                }
-                else if (nzchar(prog <- Sys.getenv("ProgramFiles")) &&
-                         length(magick.dir <- list.files(prog, "^ImageMagick.*")) &&
-                         length(magick.path <- list.files(file.path(prog,
-                                                                    magick.dir), pattern = "^convert\\.exe$", full.names = TRUE,
-                                                          recursive = TRUE))) {
+                } else if (nzchar(prog <- Sys.getenv("ProgramFiles")) &&
+                           length(magick.dir <- list.files(prog, "^ImageMagick.*")) &&
+                           length(magick.path <- list.files(file.path(prog,
+                                                                      magick.dir), pattern = "^convert\\.exe$", full.names = TRUE,
+                                                            recursive = TRUE))) {
                     convert = shQuote(normalizePath(magick.path[1]))
                     message("but I can find it from the 'Program Files' directory: ",
                             magick.path)
-                }
-                else if (!inherits(try({
+                } else if (!inherits(try({
                     magick.path = utils::readRegistry("LyX.Document\\Shell\\open\\command", "HCR")
                 }, silent = TRUE), "try-error")) {
                     convert = file.path(dirname(gsub("(^\"|\" \"%1\"$)", "", magick.path[[1]])), c("..", "../etc"), "imagemagick", "convert.exe")
@@ -153,8 +137,7 @@ im.convert = function(files, output = "animation.gif", convert = c("convert",
                 }
                 ## write it into ani.options() to save future efforts
                 ani.options(convert = convert)
-            }
-            else {
+            } else {
                 warning("Please install ImageMagick first or put its bin path into the system PATH variable")
                 return()
             }
@@ -200,17 +183,11 @@ im.convert = function(files, output = "animation.gif", convert = c("convert",
                     try(system(paste('open ', shQuote(output.path))), TRUE) else
             try(system(paste('xdg-open ', shQuote(output.path))), TRUE)
         }
-        return(invisible(output.path))
-    }
-    else {
-        message("There seems to be an error in the conversion...")
-    }
+    } else message("an error occurred in the conversion... see Notes in ?im.convert")
+    invisible(convert)
 }
-
-##' A wrapper for the `gm convert' utility of GraphicsMagick.
-##'
-##' the function \code{gm.convert} is a wrapper for the command
-##' \command{gm convert} of GraphicsMagick;
+##' @details The function \code{gm.convert} is a wrapper for the
+##' command \command{gm convert} of GraphicsMagick.
 ##' @rdname convert
 ##' @param ... arguments to be passed to \code{\link{im.convert}}
 gm.convert = function(..., convert = "gm convert") {
