@@ -1,4 +1,7 @@
-##' Demonstrate the process of k-Nearest Neighbour classification on the 2D plane.
+##' Demonstration of the k-Nearest Neighbour classification
+##'
+##' Demonstrate the process of k-Nearest Neighbour classification on
+##' the 2D plane.
 ##'
 ##' For each row of the test set, the \eqn{k} nearest (in Euclidean
 ##' distance) training set vectors are found, and the classification
@@ -48,46 +51,12 @@
 ##' \code{cl}.)
 ##' @author Yihui Xie <\url{http://yihui.name}>
 ##' @seealso \code{\link[class]{knn}}
-##' @references Venables, W. N. and Ripley, B. D. (2002) \emph{Modern Applied
-##'   Statistics with S}. Fourth edition. Springer.
+##' @references Venables, W. N. and Ripley, B. D. (2002) \emph{Modern
+##' Applied Statistics with S}. Fourth edition. Springer.
 ##'
 ##' \url{http://animation.yihui.name/dmml:k-nearest_neighbour_algorithm}
 ##' @keywords hplot iplot dynamic classif
-##' @examples
-##'
-##' ## a binary classification problem
-##' oopt = ani.options(interval = 2, nmax = ifelse(interactive(), 10, 2))
-##' x = matrix(c(rnorm(80, mean = -1), rnorm(80, mean = 1)),
-##'     ncol = 2, byrow = TRUE)
-##' y = matrix(rnorm(20, mean = 0, sd = 1.2), ncol = 2)
-##' knn.ani(train = x, test = y, cl = rep(c("first class", "second class"),
-##'     each = 40), k = 30)
-##'
-##' x = matrix(c(rnorm(30, mean = -2), rnorm(30, mean = 2),
-##'     rnorm(30, mean = 0)), ncol = 2, byrow = TRUE)
-##' y = matrix(rnorm(20, sd = 2), ncol = 2)
-##' knn.ani(train = x, test = y, cl = rep(c("first", "second", "third"),
-##'     each = 15), k = 25, cl.pch = c(2, 3, 19), dist.lty = 3)
-##'
-##' ## an interactive demo: choose the test set by mouse-clicking
-##' if (interactive()) {
-##' ani.options(nmax = 5)
-##' knn.ani(interact = TRUE)
-##' }
-##'
-##' ## HTML page
-##' saveHTML({
-##' ani.options(nmax = ifelse(interactive(), 10, 2),interval = 2)
-##' par(mar = c(3, 3, 1, 0.5), mgp = c(1.5, 0.5, 0))
-##' knn.ani(cl.pch = c(3, 19), asp = 1)
-##' }, img.name='knn_ani',htmlfile='knn.ani.html',ani.height = 500, ani.width = 600,
-##'     title = "Demonstration for kNN Classification",
-##'     description = c("For each row of the test set", 'the k nearest (in Euclidean',
-##'     'distance) training set vectors are found, and the classification is',
-##'     "decided by majority vote, with ties broken at random."))
-##'
-##' ani.options(oopt)
-##'
+##' @example inst/examples/knn.ani-ex.R
 knn.ani = function(train, test, cl, k = 10, interact = FALSE,
     tt.col = c("blue", "red"), cl.pch = seq_along(unique(cl)),
     dist.lty = 2, dist.col = "gray", knn.col = "green", ...) {
@@ -146,6 +115,7 @@ knn.ani = function(train, test, cl, k = 10, interact = FALSE,
     }
     nmax = min(nmax, nrow(test))
     for (i in 1:nmax) {
+        dev.hold()
         pre.plot(i, ...)
         ani.pause()
         idx = rank(apply(train, 1, function(x) sqrt(sum((x -
