@@ -1,4 +1,5 @@
-##' Demonstrate the least squares method.
+##' Demonstrate the least squares method
+##'
 ##' This is a simple demonstration of the meaning of least squares in
 ##' univariate linear regression.
 ##'
@@ -6,7 +7,6 @@
 ##' moving in the graph and corresponding residuals will be
 ##' plotted. We can finally see the best estimate of the intercept and
 ##' the slope from the residual plot.
-##'
 ##' @param x a numeric vector: the independent variable
 ##' @param y a numeric vector: the dependent variable
 ##' @param n the sample size: when x and y are missing, we use
@@ -32,17 +32,16 @@
 ##' residual plot
 ##' @param mfrow defines the layout of the graph; see
 ##' \code{\link[graphics]{par}}
-##' @param \dots other parameters passed to
+##' @param ... other parameters passed to
 ##' \code{\link[graphics]{plot}} to define the appearance of the
 ##' scatterplot
 ##' @return The value returned depends on the animation type.
 ##'
 ##' If it is a slope animation, the value will be a list containing
 ##' \item{lmfit}{ the estimates of the intercept and slope with
-##' \code{\link[stats]{lm}} } \item{anifit}{ the estimate of the
-##' slope in the animation } If it is an intercept animation, the
-##' second component of the above list will be the estimate of the
-##' intercept.
+##' \code{\link[stats]{lm}} } \item{anifit}{ the estimate of the slope
+##' in the animation } If it is an intercept animation, the second
+##' component of the above list will be the estimate of the intercept.
 ##'
 ##' Note the estimate will not be precise generally.
 ##' @author Yihui Xie <\url{http://yihui.name}>
@@ -51,45 +50,18 @@
 ##' steps for the slope or intercept to move.
 ##' @references \url{http://animation.yihui.name/lm:least_squares}
 ##' @keywords dynamic models
-##' @examples
-##'
-##' par(mar = c(5, 4, 0.5, 0.1))
-##' oopt = ani.options(interval = 0.3, nmax = ifelse(interactive(), 50, 2))
-##'
-##' ## default animation: with slope changing
-##' least.squares()
-##'
-##' ## intercept changing
-##' least.squares(ani.type = "intercept")
-##'
-##' ## save the animation in HTML pages
-##' saveHTML({
-##' ani.options(interval = 0.3, nmax = ifelse(interactive(), 50, 2))
-##' par(mar = c(4, 4, 0.5, 0.1), mgp = c(2, 0.5, 0), tcl = -0.3)
-##' least.squares()
-##' }, img.name='least.squares',htmlfile='least.squares.html',
-##' ani.height = 450, ani.width = 600,
-##'     title = "Demonstration of Least Squares",
-##'     description = c("We want to find an estimate for the slope",
-##'     "in 50 candidate slopes, so we just compute the RSS one by one. "))
-##'
-##' ani.options(oopt)
-##'
+##' @example inst/examples/least.squares-ex.R
 least.squares = function(x, y, n = 15, ani.type = c("slope",
     "intercept"), a, b, a.range, b.range, ab.col = c("gray",
     "black"), est.pch = 19, v.col = "red", v.lty = 2, rss.pch = 19,
     rss.type = "o", mfrow = c(1, 2), ...) {
     nmax = ani.options("nmax")
-    if (missing(x))
-        x = 1:n
-    if (missing(y))
-        y = x + rnorm(n)
+    if (missing(x)) x = 1:n
+    if (missing(y)) y = x + rnorm(n)
     ani.type = match.arg(ani.type)
     fit = coef(lm(y ~ x))
-    if (missing(a))
-        a = fit[1]
-    if (missing(b))
-        b = fit[2]
+    if (missing(a)) a = fit[1]
+    if (missing(b)) b = fit[2]
     rss = rep(NA, nmax)
     par(mfrow = mfrow)
     if (ani.type == "slope") {
@@ -97,6 +69,7 @@ least.squares = function(x, y, n = 15, ani.type = c("slope",
             bseq = tan(seq(pi/10, 3.5 * pi/10, length = nmax))
         else bseq = seq(b.range[1], b.range[2], length = nmax)
         for (i in 1:nmax) {
+            dev.hold()
             plot(x, y, ...)
             abline(fit, col = ab.col[1])
             abline(a, bseq[i], col = ab.col[2])
@@ -109,12 +82,11 @@ least.squares = function(x, y, n = 15, ani.type = c("slope",
             ani.pause()
         }
         return(invisible(list(lmfit = fit, anifit = c(x = bseq[which.min(rss)]))))
-    }
-    else if (ani.type == "intercept") {
-        if (missing(a.range))
-            aseq = seq(-5, 5, length = nmax)
-        else aseq = seq(a.range[1], a.range[2], length = nmax)
+    } else if (ani.type == "intercept") {
+        aseq = if (missing(a.range))
+            seq(-5, 5, length = nmax) else seq(a.range[1], a.range[2], length = nmax)
         for (i in 1:nmax) {
+            dev.hold()
             plot(x, y, ...)
             abline(fit, col = ab.col[1])
             abline(aseq[i], b, col = ab.col[2])
@@ -127,7 +99,5 @@ least.squares = function(x, y, n = 15, ani.type = c("slope",
             ani.pause()
         }
         return(invisible(list(lmfit = fit, anifit = c("(Intercept)" = aseq[which.min(rss)]))))
-    }
-    else warning("Incorrect animation type!")
+    } else warning("Incorrect animation type!")
 }
-
