@@ -1,15 +1,16 @@
-##' Demonstration of Law of Large Numbers.
-##' This function plots the sample mean as the sample size grows to check
-##' whether the sample mean approaches to the population mean.
+##' Demonstration of Law of Large Numbers
 ##'
-##' \code{np} points are plotted to denote the distribution of the sample mean;
-##' we will observe that the range of the sample mean just becomes smaller and
-##' smaller as the sample size increases and ultimately there will be an
-##' obvious trend that the sample mean converges to the population mean
-##' \code{mu}.
+##' This function plots the sample mean as the sample size grows to
+##' check whether the sample mean approaches to the population mean.
 ##'
-##' The parameter \code{nmax} in \code{\link{ani.options}} means the maximum
-##' sample size.
+##' \code{np} points are plotted to denote the distribution of the
+##' sample mean; we will observe that the range of the sample mean
+##' just becomes smaller and smaller as the sample size increases and
+##' ultimately there will be an obvious trend that the sample mean
+##' converges to the population mean \code{mu}.
+##'
+##' The parameter \code{nmax} in \code{\link{ani.options}} means the
+##' maximum sample size.
 ##'
 ##' @param FUN a function to generate random numbers from a certain
 ##' distribution: \code{function(n, mu)}
@@ -32,28 +33,7 @@
 ##' @references
 ##' \url{http://animation.yihui.name/prob:law_of_large_numbers}
 ##' @keywords dynamic dplot distribution
-##' @examples
-##'
-##' oopt = ani.options(interval = 0.01, nmax = ifelse(interactive(), 150, 2))
-##'
-##' lln.ani(pch = ".")
-##'
-##' ## chi-square distribution; population mean = df
-##' lln.ani(FUN = function(n, mu) rchisq(n, df = mu), mu = 5, cex = 0.6)
-##'
-##' ## save the animation in HTML pages
-##' saveHTML({
-##' par(mar = c(3, 3, 1, 0.5), mgp = c(1.5, 0.5, 0))
-##' ani.options(interval = 0.1, nmax = ifelse(interactive(), 150, 2))
-##' lln.ani(cex = 0.6)
-##' }, img.name='lln.ani',htmlfile='lln.ani.html',
-##' ani.height = 480, ani.width = 600,
-##'     title = "Demonstration of the Law of Large Numbers",
-##'     description = c("The sample mean approaches to the population mean as",
-##'     "the sample size n grows."))
-##'
-##' ani.options(oopt)
-##'
+##' @example inst/examples/lln.ani-ex.R
 lln.ani = function(FUN = rnorm, mu = 0, np = 30,
     pch = 20, col.poly = "bisque", col.mu = "gray", ...) {
     n = ani.options("nmax")
@@ -66,6 +46,7 @@ lln.ani = function(FUN = rnorm, mu = 0, np = 30,
     rg = range(m)
     xax = pretty(1:n)
     for (i in 1:n) {
+        dev.hold()
         plot(1:n, ylim = rg, type = "n", xlab = paste("n =", i),
             ylab = expression(bar(x)), xaxt = "n")
         axis(1, xax[xax <= i])
