@@ -1,8 +1,8 @@
-##' Demonstration for the cluster sampling.
-##' Each rectangle stands for a cluster, and the simple random sampling
-##' without replacement is performed for each cluster. All points in the
-##' clusters being sampled will be drawn out.
+##' Demonstration for the cluster sampling
 ##'
+##' Each rectangle stands for a cluster, and the simple random
+##' sampling without replacement is performed for each cluster. All
+##' points in the clusters being sampled will be drawn out.
 ##' @param pop a vector for the size of each cluster in the
 ##' population.
 ##' @param size the number of clusters to be drawn out.
@@ -17,24 +17,7 @@
 ##' \code{\link{sample.system}}
 ##' @references \url{http://animation.yihui.name/samp:cluster_sampling}
 ##' @keywords distribution dynamic
-##' @examples
-##' oopt = ani.options(nmax = ifelse(interactive(), 50, 2))
-##' par(mar = rep(1, 4))
-##' sample.cluster(col = c("bisque", "white"))
-##'
-##' ## HTML animation page
-##' saveHTML({
-##' par(mar = rep(1, 4), lwd = 2)
-##' ani.options(nmax = ifelse(interactive(), 50, 2))
-##' sample.cluster(col = c("bisque", "white"))
-##' }, img.name='sample.cluster',htmlfile='sample.html',
-##' ani.height = 350, ani.width = 500,
-##'     title = "Demonstration of the cluster sampling",
-##'     description = c("Once a cluster is sampled,",
-##' "all its elements will be chosen."))
-##'
-##' ani.options(oopt)
-##'
+##' @example inst/examples/sample.cluster-ex.R
 sample.cluster = function(pop = ceiling(10 * runif(10,
     0.2, 1)), size = 3, p.col = c("blue", "red"), p.cex = c(1,
     3), ...) {
@@ -44,6 +27,7 @@ sample.cluster = function(pop = ceiling(10 * runif(10,
     nrow = length(pop)
     nmax = ani.options("nmax")
     for (i in 1:nmax) {
+        dev.hold()
         plot(1, axes = FALSE, ann = FALSE, type = "n", xlim = c(0.5,
             ncol + 0.5), ylim = c(0.5, nrow + 0.5), xaxs = "i",
             yaxs = "i", xlab = "", ylab = "")
